@@ -4,7 +4,7 @@
 An exception class inspired by the tidyverse style guide.
 """
 
-from .exc import Error, info
+from .exc import Error
 
-__version__ = '0.1.0'
+__version__ = '0.2.0'
 
